@@ -16,10 +16,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: iso8859mode.c,v 1.2 2002/03/14 04:07:14 nalin Exp $"
 #include "../config.h"
 #include <stdio.h>
-#define ESC ""
+#define ESC "\033"
 
 int
 main(int argc, char **argv)
