@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: trie.c,v 1.35 2003/09/11 20:45:03 nalin Exp $"
 #include "../config.h"
 #include <sys/types.h>
 #include <assert.h>
@@ -372,7 +371,7 @@ static struct char_class char_classes[] = {
 TRIE_MAYBE_STATIC struct _vte_trie *
 _vte_trie_new(void)
 {
-	return g_malloc0(sizeof(struct _vte_trie));
+	return g_slice_new0(struct _vte_trie);
 }
 
 TRIE_MAYBE_STATIC void
@@ -385,7 +384,7 @@ _vte_trie_free(struct _vte_trie *trie)
 	if (trie->trie_path_count > 0) {
 		g_free(trie->trie_paths);
 	}
-	g_free(trie);
+	g_slice_free(struct _vte_trie, trie);
 }
 
 /* Add the given pattern, with its own result string, to the trie, with the
@@ -648,9 +647,12 @@ _vte_trie_matchx(struct _vte_trie *trie, const gunichar *pattern, size_t length,
 	/* We're done searching.  Copy out any parameters we picked up. */
 	if (bestarray != NULL) {
 		for (i = 0; i < bestarray->n_values; i++) {
-			g_value_array_append(array,
-					     g_value_array_get_nth(bestarray,
-								   i));
+			GValue *value = g_value_array_get_nth(bestarray, i);
+			g_value_array_append(array, value);
+			
+			if (G_VALUE_HOLDS_POINTER(value)) {
+				g_value_set_pointer(value, NULL);
+			}
 		}
 		_vte_matcher_free_params_array(bestarray);
 	}
@@ -704,6 +706,7 @@ _vte_trie_match(struct _vte_trie *trie, const gunichar *pattern, size_t length,
 					if (ptr != NULL) {
 						g_free(ptr);
 					}
+					g_value_set_pointer(value, NULL);
 				}
 			}
 			_vte_matcher_free_params_array(valuearray);
